summaryrefslogtreecommitdiffstats
path: root/src/usr/diag/prdf/common/plugins
diff options
context:
space:
mode:
authorCaleb Palmer <cnpalmer@us.ibm.com>2019-05-08 13:42:41 -0500
committerZane C. Shelley <zshelle@us.ibm.com>2019-06-05 10:15:34 -0500
commit57fa9ded821ced90f0a4c9d5baa26d83e6fcd1de (patch)
tree85c9e9660662f0ef9c564558a7c56e4d67c04912 /src/usr/diag/prdf/common/plugins
parent4bf4a26d8c082f8577d2182d96741e626d173411 (diff)
downloadblackbird-hostboot-57fa9ded821ced90f0a4c9d5baa26d83e6fcd1de.tar.gz
blackbird-hostboot-57fa9ded821ced90f0a4c9d5baa26d83e6fcd1de.zip
PRD: Axone misc updates for moving ecc/maint logic to OCMB
Change-Id: Ieb27008dd7aed89e938603120a0111bdef1ffc3f RTC: 207388 Reviewed-on: http://rchgit01.rchland.ibm.com/gerrit1/77154 Tested-by: Jenkins Server <pfd-jenkins+hostboot@us.ibm.com> Reviewed-by: Paul Greenwood <paul.greenwood@ibm.com> Reviewed-by: Brian J. Stegmiller <bjs@us.ibm.com> Reviewed-by: Zane C. Shelley <zshelle@us.ibm.com> Reviewed-on: http://rchgit01.rchland.ibm.com/gerrit1/78324 Tested-by: Jenkins OP Build CI <op-jenkins+hostboot@us.ibm.com> Tested-by: FSP CI Jenkins <fsp-CI-jenkins+hostboot@us.ibm.com> Tested-by: Jenkins OP HW <op-hw-jenkins+hostboot@us.ibm.com>
Diffstat (limited to 'src/usr/diag/prdf/common/plugins')
-rw-r--r--src/usr/diag/prdf/common/plugins/prdfParserUtils.C28
1 files changed, 15 insertions, 13 deletions
diff --git a/src/usr/diag/prdf/common/plugins/prdfParserUtils.C b/src/usr/diag/prdf/common/plugins/prdfParserUtils.C
index 9d2233e75..2409295c1 100644
--- a/src/usr/diag/prdf/common/plugins/prdfParserUtils.C
+++ b/src/usr/diag/prdf/common/plugins/prdfParserUtils.C
@@ -87,9 +87,9 @@ uint8_t symbol2Dq<TARGETING::TYPE_MCA>( uint8_t i_symbol )
//------------------------------------------------------------------------------
template<>
-uint8_t symbol2Dq<TARGETING::TYPE_MEM_PORT>( uint8_t i_symbol )
+uint8_t symbol2Dq<TARGETING::TYPE_OCMB_CHIP>( uint8_t i_symbol )
{
// MEM_PORT case is identical to MCA
return symbol2Dq<TARGETING::TYPE_MCA>(i_symbol);
}
@@ -122,10 +122,12 @@ uint8_t symbol2PortSlct<TARGETING::TYPE_MCA>( uint8_t i_symbol )
//------------------------------------------------------------------------------
template<>
-uint8_t symbol2PortSlct<TARGETING::TYPE_MEM_PORT>( uint8_t i_symbol )
+uint8_t symbol2PortSlct<TARGETING::TYPE_OCMB_CHIP>( uint8_t i_symbol )
{
- // Port select does not exist on MEM_PORT. Always return 0 so that code will
- // continue to work.
+ // TODO RTC 210072 - Explorer only has one port, as such we can just
+ // return 0. However, multiple ports will be supported in the future,
+ // We'll need to figure out how to convert the symbol to a port select for
+ // OCMB at that time.
return 0;
}
@@ -218,9 +220,9 @@ uint8_t nibble2Symbol<TARGETING::TYPE_MCA>( uint8_t i_x4Dram )
//------------------------------------------------------------------------------
template<>
-uint8_t nibble2Symbol<TARGETING::TYPE_MEM_PORT>( uint8_t i_x4Dram )
+uint8_t nibble2Symbol<TARGETING::TYPE_OCMB_CHIP>( uint8_t i_x4Dram )
{
// MEM_PORT case is identical to MCA
return nibble2Symbol<TARGETING::TYPE_MCA>(i_x4Dram);
}
@@ -258,9 +260,9 @@ uint8_t byte2Symbol<TARGETING::TYPE_MCA>( uint8_t i_x8Dram )
//------------------------------------------------------------------------------
template<>
-uint8_t byte2Symbol<TARGETING::TYPE_MEM_PORT>( uint8_t i_x8Dram )
+uint8_t byte2Symbol<TARGETING::TYPE_OCMB_CHIP>( uint8_t i_x8Dram )
{
// MEM_PORT case is identical to MCA
return byte2Symbol<TARGETING::TYPE_MCA>(i_x8Dram);
}
@@ -286,9 +288,9 @@ uint8_t symbol2Nibble<TARGETING::TYPE_MCA>( uint8_t i_symbol )
//------------------------------------------------------------------------------
template<>
-uint8_t symbol2Nibble<TARGETING::TYPE_MEM_PORT>( uint8_t i_symbol )
+uint8_t symbol2Nibble<TARGETING::TYPE_OCMB_CHIP>( uint8_t i_symbol )
{
// MEM_PORT case is identical to MCA
return symbol2Nibble<TARGETING::TYPE_MCA>(i_symbol);
}
@@ -314,9 +316,9 @@ uint8_t symbol2Byte<TARGETING::TYPE_MCA>( uint8_t i_symbol )
//------------------------------------------------------------------------------
template<>
-uint8_t symbol2Byte<TARGETING::TYPE_MEM_PORT>( uint8_t i_symbol )
+uint8_t symbol2Byte<TARGETING::TYPE_OCMB_CHIP>( uint8_t i_symbol )
{
// MEM_PORT case is identical to MCA
return symbol2Byte<TARGETING::TYPE_MCA>(i_symbol);
}
OpenPOWER on IntegriCloud
@@ -87,9 +87,9 @@ uint8_t symbol2Dq<TARGETING::TYPE_MCA>( uint8_t i_symbol )
{
- // MEM_PORT case is identical to MCA
+ // OCMB_CHIP case is identical to MCA
return symbol2Dq<TARGETING::TYPE_MCA>(i_symbol);
}
@@ -218,9 +220,9 @@ uint8_t nibble2Symbol<TARGETING::TYPE_MCA>( uint8_t i_x4Dram )
{
- // MEM_PORT case is identical to MCA
+ // OCMB_CHIP case is identical to MCA
return nibble2Symbol<TARGETING::TYPE_MCA>(i_x4Dram);
}
@@ -258,9 +260,9 @@ uint8_t byte2Symbol<TARGETING::TYPE_MCA>( uint8_t i_x8Dram )
{
- // MEM_PORT case is identical to MCA
+ // OCMB_CHIP case is identical to MCA
return byte2Symbol<TARGETING::TYPE_MCA>(i_x8Dram);
}
@@ -286,9 +288,9 @@ uint8_t symbol2Nibble<TARGETING::TYPE_MCA>( uint8_t i_symbol )
{
- // MEM_PORT case is identical to MCA
+ // OCMB_CHIP case is identical to MCA
return symbol2Nibble<TARGETING::TYPE_MCA>(i_symbol);
}
@@ -314,9 +316,9 @@ uint8_t symbol2Byte<TARGETING::TYPE_MCA>( uint8_t i_symbol )
{
- // MEM_PORT case is identical to MCA
+ // OCMB_CHIP case is identical to MCA
return symbol2Byte<TARGETING::TYPE_MCA>(i_symbol);
}